import { Localization, TargetCLMs } from '@ewizardjs/settings';
export type FilterOptions = boolean | string[];
export type ExcludeIncludeFilter = {
    include?: FilterOptions;
    exclude?: FilterOptions;
};
export type FilterField = string | string[] | ExcludeIncludeFilter;
export interface Block {
    id: string;
    path?: string;
    icon?: string | Record<string, string>;
    iconsPath?: string;
    clm?: FilterField;
    countries?: FilterField;
    languages?: FilterField;
    group?: string[];
    filters?: string[];
    brand?: string;
    screenshoter?: {
        skip?: boolean;
        monochrome?: boolean;
        mode?: string;
    };
}
export interface ThemeBlock extends Block {
    name?: string;
    purpose?: string[];
}
export type DefaultBlock = string | ThemeBlock;
export type DefaultBlocks = DefaultBlock[] | Record<string, DefaultBlock[]>;
export type Dictionary = Record<string, ThemeBlock>;
export interface BlocksManifest {
    components: Block[];
}
export interface ThemesBlocks {
    blocks: DefaultBlock[];
    defaultBlocks: DefaultBlocks;
}
export type BlocksThemes = Record<string, ThemesBlocks>;
export interface BlocksThemesManifest {
    themes: BlocksThemes;
}
export interface TemplateBlockData {
    name: string;
    render: () => void;
    resourcePath: string;
    slideId: string;
    staticRenderFns: () => () => void[];
    template: string;
    __componentType: string;
    __file: string;
    __i18n: string[];
    _compiled: boolean;
}
export type BlockData = Pick<ThemeBlock, 'id' | 'path' | 'purpose'>;
export type FilterBlocksOptions = {
    currentClm?: keyof typeof TargetCLMs;
    currentPurpose?: string;
    localization?: Partial<Localization>;
};
export type FilterDynamicBlocksOptions = FilterBlocksOptions & {
    blocksList: Block[];
    blocksThemes: BlocksThemes;
    currentTheme: string;
    name?: string;
};
