"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBlocksForFilter = exports.checkValueByExcludedOrIncluded = exports.validateBlockByPurposeField = exports.compareStrings = exports.getCurrentPurpose = exports.isValueInItems = exports.validateBlockByField = exports.isBlockSupported = exports.getDefaultBlocksByName = exports.parsingArrayToDictionary = exports.parseBlockData = void 0;
function parseBlockData(block) {
    if (typeof block === 'object') {
        return block;
    }
    return { id: block };
}
exports.parseBlockData = parseBlockData;
function parsingArrayToDictionary(blocks = []) {
    return blocks.reduce((dictionary, block) => {
        const blockData = parseBlockData(block);
        const { id } = blockData;
        if (id) {
            dictionary[id] = Object.assign(Object.assign({}, dictionary[id]), blockData);
        }
        return dictionary;
    }, {});
}
exports.parsingArrayToDictionary = parsingArrayToDictionary;
function getDefaultBlocksByName(blocks = {}, name = '$default') {
    var _a;
    if (Array.isArray(blocks)) {
        return blocks;
    }
    if (typeof blocks !== 'object') {
        return [];
    }
    return (_a = blocks[name]) !== null && _a !== void 0 ? _a : [];
}
exports.getDefaultBlocksByName = getDefaultBlocksByName;
function isBlockSupported(block, options) {
    const { clm, countries, purpose, languages } = block;
    const { currentClm, currentPurpose, localization = {} } = options;
    const { current: currentLanguage, country } = localization;
    const blockSupportedCurrentPurpose = validateBlockByPurposeField(purpose, currentPurpose);
    const blockSupportedCurrentClm = validateBlockByField(currentClm, clm);
    const blockSupportedCurrentCountry = validateBlockByField(country, countries);
    const blockSupportedCurrentLanguage = validateBlockByField(currentLanguage, languages);
    return blockSupportedCurrentPurpose
        && blockSupportedCurrentClm
        && blockSupportedCurrentCountry
        && blockSupportedCurrentLanguage;
}
exports.isBlockSupported = isBlockSupported;
function validateBlockByField(fieldValue = '', blockFiled) {
    if (!blockFiled) {
        return true;
    }
    if (typeof blockFiled === 'string') {
        return compareStrings(blockFiled, fieldValue.toLowerCase());
    }
    if (Array.isArray(blockFiled)) {
        return isValueInItems(blockFiled, fieldValue);
    }
    if (typeof blockFiled !== 'object') {
        return false;
    }
    return checkValueByExcludedOrIncluded(blockFiled, fieldValue);
}
exports.validateBlockByField = validateBlockByField;
function isValueInItems(items = [], value = '') {
    if (items.length) {
        const lowercaseValue = value.toLowerCase();
        return items.some((item) => compareStrings(item, lowercaseValue));
    }
    return true;
}
exports.isValueInItems = isValueInItems;
function getCurrentPurpose(metadata) {
    var _a;
    const { current: currentPurpose, default: defaultPurpose } = (_a = metadata === null || metadata === void 0 ? void 0 : metadata.purpose) !== null && _a !== void 0 ? _a : {};
    return currentPurpose !== null && currentPurpose !== void 0 ? currentPurpose : defaultPurpose;
}
exports.getCurrentPurpose = getCurrentPurpose;
function compareStrings(value, lowercaseValue) {
    return value.toLowerCase() === lowercaseValue;
}
exports.compareStrings = compareStrings;
function validateBlockByPurposeField(purpose, purposeValue) {
    if (!purposeValue || !purpose) {
        return true;
    }
    if (Array.isArray(purpose)) {
        return Boolean(purpose.length) && isValueInItems(purpose, purposeValue);
    }
    if (typeof purpose !== 'object') {
        return false;
    }
    return checkValueByExcludedOrIncluded(purpose, purposeValue);
}
exports.validateBlockByPurposeField = validateBlockByPurposeField;
function checkValueByExcludedOrIncluded(fieldObject = {}, fieldValue = '') {
    const { exclude, include } = fieldObject;
    if (checkExcludeField(exclude, fieldValue)) {
        return false;
    }
    return checkIncludeField(include, fieldValue);
}
exports.checkValueByExcludedOrIncluded = checkValueByExcludedOrIncluded;
function checkExcludeField(exclude = [], fieldValue) {
    if (typeof exclude === 'boolean') {
        return exclude;
    }
    if (typeof exclude !== 'object') {
        return true;
    }
    return Boolean(exclude.length) && isValueInItems(exclude, fieldValue);
}
function checkIncludeField(include = [], fieldValue) {
    if (typeof include === 'boolean') {
        return include;
    }
    if (typeof include !== 'object') {
        return false;
    }
    return isValueInItems(include, fieldValue);
}
function getBlocksForFilter(blocksList, themeBlocks = []) {
    return themeBlocks.length
        ? themeBlocks
        : blocksList;
}
exports.getBlocksForFilter = getBlocksForFilter;
//# sourceMappingURL=index.js.map